CecDevice1Proxy

Struct CecDevice1Proxy 

pub struct CecDevice1Proxy<'p>(/* private fields */);

Implementations

Source

impl<'p> CecDevice1Proxy<'p>

pub async fn new(conn: &Connection) -> Result<CecDevice1Proxy<'p>>

Creates a new proxy with the default service and path.

pub fn builder(conn: &Connection) -> Builder<'p, Self>

Returns a customizable builder for this proxy.

pub fn into_inner(self) -> Proxy<'p>

Consumes self, returning the underlying zbus::Proxy.

pub fn inner(&self) -> &Proxy<'p>

The reference to the underlying zbus::Proxy.

pub fn inner_mut(&mut self) -> &mut Proxy<'p>

The mutable reference to the underlying zbus::Proxy.

pub async fn get_audio_status(&self, target: u8) -> Result<(u8, bool)>

GetAudioStatus method

pub async fn mute(&self, target: u8) -> Result<()>

Mute method

pub async fn poll(&self, target: u8) -> Result<()>

Poll method

pub async fn press_once_user_control( &self, button: &[u8], target: u8, ) -> Result<()>

PressOnceUserControl method

pub async fn press_user_control(&self, button: &[u8], target: u8) -> Result<()>

PressUserControl method

pub async fn release_user_control(&self, target: u8) -> Result<()>

ReleaseUserControl method

pub async fn send_raw_message( &self, raw_message: &[u8], target: u8, ) -> Result<u32>

SendRawMessage method

pub async fn send_receive_raw_message( &self, raw_message: &[u8], target: u8, opcode: u8, timeout: u16, ) -> Result<Vec<u8>>

SendReceiveRawMessage method

pub async fn set_active_source(&self, phys_addr: i32) -> Result<()>

SetActiveSource method

pub async fn set_osd_name(&self, name: &str) -> Result<()>

SetOsdName method

pub async fn standby(&self, target: u8) -> Result<()>

Standby method

pub async fn volume_down(&self, target: u8) -> Result<()>

VolumeDown method

pub async fn volume_up(&self, target: u8) -> Result<()>

VolumeUp method

pub async fn wake(&self) -> Result<()>

Wake method

pub async fn receive_received_message(&self) -> Result<ReceivedMessageStream>

Create a stream that receives ReceivedMessage signals.

This a convenient wrapper around zbus::Proxy::receive_signal. ReceivedMessage signal

pub async fn receive_received_message_with_args( &self, args: &[(u8, &str)], ) -> Result<ReceivedMessageStream>

Create a stream that receives ReceivedMessage signals.

This a convenient wrapper around zbus::Proxy::receive_signal_with_args. ReceivedMessage signal

pub async fn receive_user_control_pressed( &self, ) -> Result<UserControlPressedStream>

Create a stream that receives UserControlPressed signals.

This a convenient wrapper around zbus::Proxy::receive_signal. UserControlPressed signal

pub async fn receive_user_control_pressed_with_args( &self, args: &[(u8, &str)], ) -> Result<UserControlPressedStream>

Create a stream that receives UserControlPressed signals.

This a convenient wrapper around zbus::Proxy::receive_signal_with_args. UserControlPressed signal

pub async fn receive_user_control_released( &self, ) -> Result<UserControlReleasedStream>

Create a stream that receives UserControlReleased signals.

This a convenient wrapper around zbus::Proxy::receive_signal. UserControlReleased signal

pub async fn receive_user_control_released_with_args( &self, args: &[(u8, &str)], ) -> Result<UserControlReleasedStream>

Create a stream that receives UserControlReleased signals.

This a convenient wrapper around zbus::Proxy::receive_signal_with_args. UserControlReleased signal

pub async fn active(&self) -> Result<bool>

Active property

pub fn cached_active( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Active property Get the cached value of the Active property, or None if the property is not cached.

pub async fn receive_active_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>

Active property Create a stream for the Active property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn logical_addresses(&self) -> Result<Vec<u8>>

LogicalAddresses property

pub fn cached_logical_addresses( &self, ) -> Result<Option<<Result<Vec<u8>> as ResultAdapter>::Ok>, <Result<Vec<u8>> as ResultAdapter>::Err>

LogicalAddresses property Get the cached value of the LogicalAddresses property, or None if the property is not cached.

pub async fn receive_logical_addresses_changed( &self, ) -> PropertyStream<'p, <Result<Vec<u8>> as ResultAdapter>::Ok>

LogicalAddresses property Create a stream for the LogicalAddresses property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn physical_address(&self) -> Result<u16>

PhysicalAddress property

pub fn cached_physical_address( &self, ) -> Result<Option<<Result<u16> as ResultAdapter>::Ok>, <Result<u16> as ResultAdapter>::Err>

PhysicalAddress property Get the cached value of the PhysicalAddress property, or None if the property is not cached.

pub async fn receive_physical_address_changed( &self, ) -> PropertyStream<'p, <Result<u16> as ResultAdapter>::Ok>

PhysicalAddress property Create a stream for the PhysicalAddress property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.

pub async fn vendor_id(&self) -> Result<i32>

VendorId property

pub fn cached_vendor_id( &self, ) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>

VendorId property Get the cached value of the VendorId property, or None if the property is not cached.

pub async fn receive_vendor_id_changed( &self, ) -> PropertyStream<'p, <Result<i32> as ResultAdapter>::Ok>

VendorId property Create a stream for the VendorId property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.