pub struct Config1Proxy<'p>(/* private fields */);Implementations
Sourceimpl<'p> Config1Proxy<'p>
impl<'p> Config1Proxy<'p>
Sourcepub async fn new(conn: &Connection) -> Result<Config1Proxy<'p>>
pub async fn new(conn: &Connection) -> Result<Config1Proxy<'p>>
Creates a new proxy with the default service and path.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
Sourcepub async fn allow_standby(&self) -> Result<bool>
pub async fn allow_standby(&self) -> Result<bool>
AllowStandby property
Sourcepub fn cached_allow_standby(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_allow_standby( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
AllowStandby property
Get the cached value of the AllowStandby property, or None if the property is not cached.
Sourcepub async fn receive_allow_standby_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_allow_standby_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
AllowStandby property
Create a stream for the AllowStandby property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub fn cached_uinput(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_uinput( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
Uinput property
Get the cached value of the Uinput property, or None if the property is not cached.
Sourcepub async fn receive_uinput_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_uinput_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
Uinput property
Create a stream for the Uinput property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn logical_address(&self) -> Result<u8>
pub async fn logical_address(&self) -> Result<u8>
LogicalAddress property
Sourcepub fn cached_logical_address(
&self,
) -> Result<Option<<Result<u8> as ResultAdapter>::Ok>, <Result<u8> as ResultAdapter>::Err>
pub fn cached_logical_address( &self, ) -> Result<Option<<Result<u8> as ResultAdapter>::Ok>, <Result<u8> as ResultAdapter>::Err>
LogicalAddress property
Get the cached value of the LogicalAddress property, or None if the property is not cached.
Sourcepub async fn receive_logical_address_changed(
&self,
) -> PropertyStream<'p, <Result<u8> as ResultAdapter>::Ok>
pub async fn receive_logical_address_changed( &self, ) -> PropertyStream<'p, <Result<u8> as ResultAdapter>::Ok>
LogicalAddress property
Create a stream for the LogicalAddress property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub fn cached_mappings(
&self,
) -> Result<Option<<Result<Vec<(Vec<u8>, u16)>> as ResultAdapter>::Ok>, <Result<Vec<(Vec<u8>, u16)>> as ResultAdapter>::Err>
pub fn cached_mappings( &self, ) -> Result<Option<<Result<Vec<(Vec<u8>, u16)>> as ResultAdapter>::Ok>, <Result<Vec<(Vec<u8>, u16)>> as ResultAdapter>::Err>
Mappings property
Get the cached value of the Mappings property, or None if the property is not cached.
Sourcepub async fn receive_mappings_changed(
&self,
) -> PropertyStream<'p, <Result<Vec<(Vec<u8>, u16)>> as ResultAdapter>::Ok>
pub async fn receive_mappings_changed( &self, ) -> PropertyStream<'p, <Result<Vec<(Vec<u8>, u16)>> as ResultAdapter>::Ok>
Mappings property
Create a stream for the Mappings property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub fn cached_osd_name(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_osd_name( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
OsdName property
Get the cached value of the OsdName property, or None if the property is not cached.
Sourcepub async fn receive_osd_name_changed(
&self,
) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
pub async fn receive_osd_name_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
OsdName property
Create a stream for the OsdName property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn suspend_tv(&self) -> Result<bool>
pub async fn suspend_tv(&self) -> Result<bool>
SuspendTv property
Sourcepub fn cached_suspend_tv(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_suspend_tv( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
SuspendTv property
Get the cached value of the SuspendTv property, or None if the property is not cached.
Sourcepub async fn receive_suspend_tv_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_suspend_tv_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
SuspendTv property
Create a stream for the SuspendTv property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub fn cached_vendor_id(
&self,
) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>
pub fn cached_vendor_id( &self, ) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>
VendorId property
Get the cached value of the VendorId property, or None if the property is not cached.
Sourcepub async fn receive_vendor_id_changed(
&self,
) -> PropertyStream<'p, <Result<i32> as ResultAdapter>::Ok>
pub async fn receive_vendor_id_changed( &self, ) -> PropertyStream<'p, <Result<i32> as ResultAdapter>::Ok>
VendorId property
Create a stream for the VendorId property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub fn cached_wake_tv(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_wake_tv( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
WakeTv property
Get the cached value of the WakeTv property, or None if the property is not cached.
Sourcepub async fn receive_wake_tv_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_wake_tv_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
WakeTv property
Create a stream for the WakeTv property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.