pub struct Daemon1Proxy<'p>(/* private fields */);Implementations
Sourceimpl<'p> Daemon1Proxy<'p>
impl<'p> Daemon1Proxy<'p>
Sourcepub async fn new(conn: &Connection) -> Result<Daemon1Proxy<'p>>
pub async fn new(conn: &Connection) -> Result<Daemon1Proxy<'p>>
Creates a new proxy with the default service and path.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
Sourcepub async fn register_message_handler(
&self,
opcode: u8,
path: &ObjectPath<'_>,
ok: bool,
) -> Result<()>
pub async fn register_message_handler( &self, opcode: u8, path: &ObjectPath<'_>, ok: bool, ) -> Result<()>
RegisterMessageHandler method
Sourcepub async fn unregister_message_handler(
&self,
opcode: u8,
ok: bool,
) -> Result<()>
pub async fn unregister_message_handler( &self, opcode: u8, ok: bool, ) -> Result<()>
UnregisterMessageHandler method
Sourcepub async fn handled_messages(&self) -> Result<Vec<u8>>
pub async fn handled_messages(&self) -> Result<Vec<u8>>
HandledMessages property
Sourcepub fn cached_handled_messages(
&self,
) -> Result<Option<<Result<Vec<u8>> as ResultAdapter>::Ok>, <Result<Vec<u8>> as ResultAdapter>::Err>
pub fn cached_handled_messages( &self, ) -> Result<Option<<Result<Vec<u8>> as ResultAdapter>::Ok>, <Result<Vec<u8>> as ResultAdapter>::Err>
HandledMessages property
Get the cached value of the HandledMessages property, or None if the property is not cached.
Sourcepub async fn receive_handled_messages_changed(
&self,
) -> PropertyStream<'p, <Result<Vec<u8>> as ResultAdapter>::Ok>
pub async fn receive_handled_messages_changed( &self, ) -> PropertyStream<'p, <Result<Vec<u8>> as ResultAdapter>::Ok>
HandledMessages property
Create a stream for the HandledMessages property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.