pub struct CecDevice1Proxy<'p>(/* private fields */);Implementations
Sourceimpl<'p> CecDevice1Proxy<'p>
impl<'p> CecDevice1Proxy<'p>
Sourcepub async fn new(conn: &Connection) -> Result<CecDevice1Proxy<'p>>
pub async fn new(conn: &Connection) -> Result<CecDevice1Proxy<'p>>
Creates a new proxy with the default service and path.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
Sourcepub async fn press_once_user_control(
&self,
button: &[u8],
target: u8,
) -> Result<()>
pub async fn press_once_user_control( &self, button: &[u8], target: u8, ) -> Result<()>
PressOnceUserControl method
Sourcepub async fn press_user_control(&self, button: &[u8], target: u8) -> Result<()>
pub async fn press_user_control(&self, button: &[u8], target: u8) -> Result<()>
PressUserControl method
Sourcepub async fn release_user_control(&self, target: u8) -> Result<()>
pub async fn release_user_control(&self, target: u8) -> Result<()>
ReleaseUserControl method
Sourcepub async fn send_raw_message(
&self,
raw_message: &[u8],
target: u8,
) -> Result<u32>
pub async fn send_raw_message( &self, raw_message: &[u8], target: u8, ) -> Result<u32>
SendRawMessage method
Sourcepub async fn send_receive_raw_message(
&self,
raw_message: &[u8],
target: u8,
opcode: u8,
timeout: u16,
) -> Result<Vec<u8>>
pub async fn send_receive_raw_message( &self, raw_message: &[u8], target: u8, opcode: u8, timeout: u16, ) -> Result<Vec<u8>>
SendReceiveRawMessage method
Sourcepub async fn set_active_source(&self, phys_addr: i32) -> Result<()>
pub async fn set_active_source(&self, phys_addr: i32) -> Result<()>
SetActiveSource method
Sourcepub async fn set_osd_name(&self, name: &str) -> Result<()>
pub async fn set_osd_name(&self, name: &str) -> Result<()>
SetOsdName method
Sourcepub async fn volume_down(&self, target: u8) -> Result<()>
pub async fn volume_down(&self, target: u8) -> Result<()>
VolumeDown method
Sourcepub async fn receive_received_message(&self) -> Result<ReceivedMessageStream>
pub async fn receive_received_message(&self) -> Result<ReceivedMessageStream>
Create a stream that receives ReceivedMessage signals.
This a convenient wrapper around zbus::Proxy::receive_signal.
ReceivedMessage signal
Sourcepub async fn receive_received_message_with_args(
&self,
args: &[(u8, &str)],
) -> Result<ReceivedMessageStream>
pub async fn receive_received_message_with_args( &self, args: &[(u8, &str)], ) -> Result<ReceivedMessageStream>
Create a stream that receives ReceivedMessage signals.
This a convenient wrapper around zbus::Proxy::receive_signal_with_args.
ReceivedMessage signal
Sourcepub async fn receive_user_control_pressed(
&self,
) -> Result<UserControlPressedStream>
pub async fn receive_user_control_pressed( &self, ) -> Result<UserControlPressedStream>
Create a stream that receives UserControlPressed signals.
This a convenient wrapper around zbus::Proxy::receive_signal.
UserControlPressed signal
Sourcepub async fn receive_user_control_pressed_with_args(
&self,
args: &[(u8, &str)],
) -> Result<UserControlPressedStream>
pub async fn receive_user_control_pressed_with_args( &self, args: &[(u8, &str)], ) -> Result<UserControlPressedStream>
Create a stream that receives UserControlPressed signals.
This a convenient wrapper around zbus::Proxy::receive_signal_with_args.
UserControlPressed signal
Sourcepub async fn receive_user_control_released(
&self,
) -> Result<UserControlReleasedStream>
pub async fn receive_user_control_released( &self, ) -> Result<UserControlReleasedStream>
Create a stream that receives UserControlReleased signals.
This a convenient wrapper around zbus::Proxy::receive_signal.
UserControlReleased signal
Sourcepub async fn receive_user_control_released_with_args(
&self,
args: &[(u8, &str)],
) -> Result<UserControlReleasedStream>
pub async fn receive_user_control_released_with_args( &self, args: &[(u8, &str)], ) -> Result<UserControlReleasedStream>
Create a stream that receives UserControlReleased signals.
This a convenient wrapper around zbus::Proxy::receive_signal_with_args.
UserControlReleased signal
Sourcepub fn cached_active(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_active( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
Active property
Get the cached value of the Active property, or None if the property is not cached.
Sourcepub async fn receive_active_changed(
&self,
) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
pub async fn receive_active_changed( &self, ) -> PropertyStream<'p, <Result<bool> as ResultAdapter>::Ok>
Active property
Create a stream for the Active property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn logical_addresses(&self) -> Result<Vec<u8>>
pub async fn logical_addresses(&self) -> Result<Vec<u8>>
LogicalAddresses property
Sourcepub fn cached_logical_addresses(
&self,
) -> Result<Option<<Result<Vec<u8>> as ResultAdapter>::Ok>, <Result<Vec<u8>> as ResultAdapter>::Err>
pub fn cached_logical_addresses( &self, ) -> Result<Option<<Result<Vec<u8>> as ResultAdapter>::Ok>, <Result<Vec<u8>> as ResultAdapter>::Err>
LogicalAddresses property
Get the cached value of the LogicalAddresses property, or None if the property is not cached.
Sourcepub async fn receive_logical_addresses_changed(
&self,
) -> PropertyStream<'p, <Result<Vec<u8>> as ResultAdapter>::Ok>
pub async fn receive_logical_addresses_changed( &self, ) -> PropertyStream<'p, <Result<Vec<u8>> as ResultAdapter>::Ok>
LogicalAddresses property
Create a stream for the LogicalAddresses property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn physical_address(&self) -> Result<u16>
pub async fn physical_address(&self) -> Result<u16>
PhysicalAddress property
Sourcepub fn cached_physical_address(
&self,
) -> Result<Option<<Result<u16> as ResultAdapter>::Ok>, <Result<u16> as ResultAdapter>::Err>
pub fn cached_physical_address( &self, ) -> Result<Option<<Result<u16> as ResultAdapter>::Ok>, <Result<u16> as ResultAdapter>::Err>
PhysicalAddress property
Get the cached value of the PhysicalAddress property, or None if the property is not cached.
Sourcepub async fn receive_physical_address_changed(
&self,
) -> PropertyStream<'p, <Result<u16> as ResultAdapter>::Ok>
pub async fn receive_physical_address_changed( &self, ) -> PropertyStream<'p, <Result<u16> as ResultAdapter>::Ok>
PhysicalAddress property
Create a stream for the PhysicalAddress property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub fn cached_vendor_id(
&self,
) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>
pub fn cached_vendor_id( &self, ) -> Result<Option<<Result<i32> as ResultAdapter>::Ok>, <Result<i32> as ResultAdapter>::Err>
VendorId property
Get the cached value of the VendorId property, or None if the property is not cached.
Sourcepub async fn receive_vendor_id_changed(
&self,
) -> PropertyStream<'p, <Result<i32> as ResultAdapter>::Ok>
pub async fn receive_vendor_id_changed( &self, ) -> PropertyStream<'p, <Result<i32> as ResultAdapter>::Ok>
VendorId property
Create a stream for the VendorId property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.